<?php
include('includes/header.php'); // Include your database connection file
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Calculate the previous month
$currentYear = date('Y');
$currentMonth = date('m');

if ($currentMonth == '01') {
    // If the current month is January, set the previous month to December of the previous year
    $previousMonth = '12';
    $previousYear = $currentYear - 1;
} else {
    // For other months, simply subtract 1 from the current month
    $previousMonth = sprintf('%02d', $currentMonth - 1); // Ensure 2-digit format
    $previousYear = $currentYear;
}

// Calculate the date for April and Sept
$marchDate = $currentYear . '-03-01';
$septDate = $currentYear . '-09-01';

// Calculate the start and end months for cumulative direct labor
$startMonth = $currentYear . '-04-01';
$endMonth = $currentYear . '-09-30';

// Check if the form was submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Handle form submission here if needed
    // ...

    // Redirect back to the same page after handling the form data
    header("Location: totalProjectIncome.php");
    exit();
}

// Query to retrieve the Total MIS Income for the previous month from the database
$queryTotal = "SELECT total_mis_income FROM mis_income_cum WHERE month = '$previousYear-$previousMonth-01'";

$resultTotal = mysqli_query($conn, $queryTotal);

if (!$resultTotal) {
    die("Total Query failed: " . mysqli_error($conn));
}

// Fetch the Total MIS Income value
$rowTotal = mysqli_fetch_assoc($resultTotal);
$misIncomeTotal = $rowTotal['total_mis_income'];

// Query to fetch milestone data for April and Sept, including client name
$query = "
    SELECT clients.clientName, projects.projectName, milestones.milestoneName, milestones.milestoneValue,
           MAX(CASE WHEN DATE_FORMAT(date, '%Y-%m') = '$currentYear-03' THEN perCompletion END) AS perCompletionMarch,
           MAX(CASE WHEN DATE_FORMAT(date, '%Y-%m') = '$currentYear-09' THEN perCompletion END) AS perCompletionSept,
           SUM(users.employeeRate * (timesheet.hrs / 8)) AS CumulativeDL
    FROM milestones
    INNER JOIN projects ON milestones.projectID = projects.projectID
    INNER JOIN clients ON projects.clientID = clients.clientID
    LEFT JOIN perCompletion ON milestones.milestoneID = perCompletion.milestoneID
    LEFT JOIN timesheet ON milestones.milestoneID = timesheet.milestoneID
    LEFT JOIN users ON timesheet.userID = users.userID
    WHERE DATE_FORMAT(date, '%Y-%m') IN ('$currentYear-03', '$currentYear-09')
    GROUP BY clients.clientName, projects.projectName, milestones.milestoneName
    ORDER BY clients.clientName ASC, projects.projectName ASC, milestones.milestoneName ASC
";

$result = mysqli_query($conn, $query);

if (!$result) {
    die("Query failed: " . mysqli_error($conn));
}

// Initialize an associative array to store the total income for each project
$projectTotalIncome = array();

// Fetch and store project income data
while ($row = mysqli_fetch_assoc($result)) {
    $projectName = $row['projectName'];
    $milestoneValue = $row['milestoneValue'];
    $perCompletionMarch = $row['perCompletionMarch'];
    $perCompletionSept = $row['perCompletionSept'];

    if ($perCompletionMarch != 100) {
        // Calculate milestoneIncome for the current milestone
        $milestoneIncome = $milestoneValue * (($perCompletionSept - $perCompletionMarch) / 100);

        // Accumulate the milestoneIncome into the projectIncome total for the current project
        if (!isset($projectTotalIncome[$projectName])) {
            $projectTotalIncome[$projectName] = 0;
        }

        $projectTotalIncome[$projectName] += $milestoneIncome;
    }
}

// Query to fetch Cumulative Project Direct Labour and Direct Material Cost
$queryCumulative = "SELECT clients.clientName, projects.projectName, 
                          SUM(users.employeeRate * (timesheet.hrs / 8)) AS CumulativeDL, 
                          projects.directMaterialcost AS CumulativeDM
                   FROM timesheet
                   INNER JOIN milestones ON timesheet.milestoneID = milestones.milestoneID
                   INNER JOIN projects ON milestones.projectID = projects.projectID
                   INNER JOIN clients ON projects.clientID = clients.clientID
                   INNER JOIN users ON timesheet.userID = users.userID
                   WHERE timesheet.tentryDate BETWEEN '$startMonth' AND '$endMonth'
                   GROUP BY clients.clientName, projects.projectName
                   ORDER BY CumulativeDL DESC";

$resultCumulative = mysqli_query($conn, $queryCumulative);

if (!$resultCumulative) {
    die("Query failed: " . mysqli_error($conn));
}

// Initialize an associative array to store Cumulative Direct Labour and Direct Material Cost
$projectCumulative = array();

// Fetch and store Cumulative data
while ($rowCumulative = mysqli_fetch_assoc($resultCumulative)) {
    $projectName = $rowCumulative['projectName'];
    $cumulativeDL = $rowCumulative['CumulativeDL'];
    $cumulativeDM = $rowCumulative['CumulativeDM'];

    $projectCumulative[$projectName] = [
        'CumulativeDL' => $cumulativeDL,
        'CumulativeDM' => $cumulativeDM,
    ];
}

// Calculate and store the Total Contribution and Contribution Percentage for each project
$projectTotalContribution = array();

foreach ($projectTotalIncome as $projectName => $totalIncome) {
    if (isset($projectCumulative[$projectName])) {
        $cumulativeDL = $projectCumulative[$projectName]['CumulativeDL'];
        $cumulativeDM = $projectCumulative[$projectName]['CumulativeDM'];
        $totalContribution = $totalIncome - $cumulativeDL - $cumulativeDM;
        $contributionPercentage = ($totalContribution / $totalIncome) * 100;
        $projectTotalContribution[$projectName] = [
            'TotalContribution' => $totalContribution,
            'ContributionPercentage' => $contributionPercentage,
        ];
    } else {
        $projectTotalContribution[$projectName] = null;
    }
}

// Sort the projects by Total Contribution in descending order
arsort($projectTotalContribution);

// Output the Combined Table
echo "<!DOCTYPE html>";
echo "<html lang='en'>";
echo "<head>";
echo "<meta charset='UTF-8'>";
echo "<meta name='viewport' content='width=device-width, initial-scale=1.0'>";
echo "<title>Total Project Contribution</title>";
echo "<script type='text/javascript' src='https://www.gstatic.com/charts/loader.js'></script>";
echo "</head>";
echo "<body>";
echo "<h1>Total Project Contribution</h1>";
echo "<button id='download-csv' class='btn btn-primary float-end' style='margin-bottom: 10px;'>Download CSV</button>";
echo "<table class='table table-bordered table-striped'>";
echo "<thead>";
echo "<tr>";
echo "<th>S.No.</th>"; // Add S.No. column header
echo "<th>Project Name</th>";
echo "<th>Project Total Income</th>";
echo "<th>Cumulative Direct Labour</th>";
echo "<th>Cumulative Direct Material Cost</th>";
echo "<th>Total Contribution</th>"; // Add Total Contribution column header
echo "<th>Project Contribution Percentage</th>"; // Add Contribution Percentage column header
echo "</tr>";
echo "</thead>";
echo "<tbody>";

// Initialize a counter for S.No.
$serialNumber = 1;

foreach ($projectTotalContribution as $projectName => $contributionData) {
    echo "<tr>";
    echo "<td>$serialNumber</td>"; // Output the S.No.
    echo "<td>$projectName</td>";
    echo "<td>" . number_format($projectTotalIncome[$projectName], 2) . "</td>";

    if (isset($projectCumulative[$projectName])) {
        echo "<td>" . number_format($projectCumulative[$projectName]['CumulativeDL'], 2) . "</td>";
        echo "<td>" . number_format($projectCumulative[$projectName]['CumulativeDM'], 2) . "</td>";
    } else {
        echo "<td>N/A</td>";
        echo "<td>N/A</td>";
    }

    if ($contributionData !== null) {
        echo "<td>" . number_format($contributionData['TotalContribution'], 2) . "</td>";
        echo "<td>" . number_format($contributionData['ContributionPercentage'], 2) . "%</td>";
    } else {
        echo "<td>N/A</td>";
        echo "<td>N/A</td>";
    }

    echo "</tr>";

    $serialNumber++; // Increment the S.No.
}

echo "</tbody>";
echo "</table>";

echo "</body>";
echo "</html>";

// Close the database connection if needed
mysqli_close($conn);
?>
<script>
        // Function to trigger CSV download
        function downloadCSV() {
            const table = document.querySelector('.table');
            const rows = table.querySelectorAll('tr');
            const csv = [];

            // Generate CSV content
            rows.forEach((row, rowIndex) => {
                const rowData = [];
                row.querySelectorAll('td, th').forEach((cell, cellIndex) => {
                    // Wrap cell data in double quotes and escape existing double quotes
                    const cellData = cell.textContent.replace(/"/g, '""');
                    rowData.push(`"${cellData}"`);
                });

                // Include the header row if it's the first row
                if (rowIndex === 0) {
                    csv.push(rowData.join(','));
                } else {
                    csv.push(rowData.join(','));
                }
            });

            // Create a blob containing the CSV data
            const blob = new Blob([csv.join('\n')], { type: 'text/csv' });

            // Create a download link and trigger the download
            const link = document.createElement('a');
            link.href = URL.createObjectURL(blob);
            link.download = 'project_income.csv';
            link.style display = 'none';
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        }

        // Add click event listener to the download button
        document.getElementById('download-csv').addEventListener('click', downloadCSV);
</script>