<?php
include('includes/header.php'); // Include your database connection file
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Calculate the financial year starting from April and ending in March
$currentYear = date('Y');
$previousYear = $currentYear - 1;
$today = new DateTime();

// Check if the current month is January
if ($today->format('m') == '01') {
    $currentYear -= 1; // Adjust to the previous year
}

$startMonth = $currentYear . '-04-01';
$endMonth = $currentYear . '-08-31';

// Check if the form was submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Handle form submission here if needed
    // ...

    // Redirect back to the same page after handling the form data
    header("Location: totalProjectIncome.php");
    exit();
}

// Query to retrieve the Total MIS Income for the previous month from the database
$queryTotal = "SELECT total_mis_income FROM mis_income_cum WHERE month = '$currentYear-08-01'";
$resultTotal = mysqli_query($conn, $queryTotal);

if (!$resultTotal) {
    die("Total Query failed: " . mysqli_error($conn));
}

// Fetch the Total MIS Income value
$rowTotal = mysqli_fetch_assoc($resultTotal);
$misIncomeTotal = $rowTotal['total_mis_income'];

// Query to fetch milestone data for April and March, including client name
$query = "SELECT projects.contractValue, clients.clientName, projects.projectName, milestones.milestoneName, milestones.milestoneValue,
           MAX(CASE WHEN DATE_FORMAT(date, '%Y-%m') = '$currentYear-03' THEN perCompletion END) AS perCompletionMarch,
           MAX(CASE WHEN DATE_FORMAT(date, '%Y-%m') = '$currentYear-08' THEN perCompletion ELSE CASE WHEN DATE_FORMAT(date, '%Y-%m') = '$currentYear-07' THEN perCompletion END END) AS perCompletionAugust,
           MAX(CASE WHEN DATE_FORMAT(date, '%Y-%m') = '$currentYear-07' THEN perCompletion END) AS perCompletionJuly,
           SUM(users.employeeRate * (timesheet.hrs / 8)) AS CumulativeDL
    FROM milestones
    INNER JOIN projects ON milestones.projectID = projects.projectID
    INNER JOIN clients ON projects.clientID = clients.clientID
    LEFT JOIN perCompletion ON milestones.milestoneID = perCompletion.milestoneID
    LEFT JOIN timesheet ON milestones.milestoneID = timesheet.milestoneID
    LEFT JOIN users ON timesheet.userID = users.userID
    WHERE DATE_FORMAT(date, '%Y-%m') IN ('$currentYear-03', '$currentYear-08', '$currentYear-07')
    GROUP BY clients.clientName, projects.projectName, milestones.milestoneName
    ORDER BY clients.clientName ASC, projects.projectName ASC, milestones.milestoneName ASC";

$result = mysqli_query($conn, $query);

if (!$result) {
    die("Query failed: " . mysqli_error($conn));
}

// Initialize arrays to store project data
$projectTotalIncome = [];
$projectClientNames = [];

// Fetch and store project income data
while ($row = mysqli_fetch_assoc($result)) {
    $projectName = $row['projectName'];
    $clientName = $row['clientName'];
    $milestoneValue = $row['milestoneValue'];
    $perCompletionMarch = $row['perCompletionMarch'];
    $perCompletionAugust = $row['perCompletionAugust'];
    $perCompletionJuly = $row['perCompletionJuly'];

    // Store the clientName for the project
    $projectClientNames[$projectName] = $clientName;

    if ($perCompletionMarch != 100) {
        // Calculate milestoneIncome for the current milestone
        if ($perCompletionAugust !== null) {
            $milestoneIncome = $milestoneValue * (($perCompletionAugust - $perCompletionMarch) / 100);
        } else {
            $milestoneIncome = $milestoneValue * (($perCompletionJuly - $perCompletionMarch) / 100);
        }

        // Accumulate the milestoneIncome into the projectIncome total for the current project
        if (!isset($projectTotalIncome[$projectName])) {
            $projectTotalIncome[$projectName] = 0;
        }

        $projectTotalIncome[$projectName] += $milestoneIncome;
    }
}

// Query to fetch Cumulative Project Direct Labour and Direct Material Cost
$queryCumulative = "SELECT clients.clientName, projects.projectName, 
                          SUM(users.employeeRate * (timesheet.hrs / 8)) AS CumulativeDL, 
                          projects.directMaterialcost AS CumulativeDM,
                          projects.contractValue AS ContractValue
                   FROM timesheet
                   INNER JOIN milestones ON timesheet.milestoneID = milestones.milestoneID
                   INNER JOIN projects ON milestones.projectID = projects.projectID
                   INNER JOIN clients ON projects.clientID = clients.clientID
                   INNER JOIN users ON timesheet.userID = users.userID
                   WHERE timesheet.tentryDate BETWEEN '$startMonth' AND '$endMonth'
                   GROUP BY clients.clientName, projects.projectName
                   ORDER BY CumulativeDL DESC";

$resultCumulative = mysqli_query($conn, $queryCumulative);

if (!$resultCumulative) {
    die("Query failed: " . mysqli_error($conn));
}

// Initialize an associative array to store Cumulative Direct Labour and Direct Material Cost
$projectCumulative = [];

// Fetch and store Cumulative data
while ($rowCumulative = mysqli_fetch_assoc($resultCumulative)) {
    $projectName = $rowCumulative['projectName'];
    $cumulativeDL = $rowCumulative['CumulativeDL'];
    $cumulativeDM = $rowCumulative['CumulativeDM'];
    $contractValue = $rowCumulative['ContractValue'];

    $projectCumulative[$projectName] = [
        'CumulativeDL' => $cumulativeDL,
        'CumulativeDM' => $cumulativeDM,
        'ContractValue' => $contractValue,
    ];
}

// Calculate and store the Total Contribution and Contribution Percentage for each project
$projectTotalContribution = [];

foreach ($projectTotalIncome as $projectName => $totalIncome) {
    if (isset($projectCumulative[$projectName])) {
        $cumulativeDL = $projectCumulative[$projectName]['CumulativeDL'];
        $cumulativeDM = $projectCumulative[$projectName]['CumulativeDM'];
        $totalContribution = $totalIncome - $cumulativeDL - $cumulativeDM;

        if ($totalIncome != 0) {
            $contributionPercentage = ($totalContribution / $totalIncome) * 100;
        } else {
            $contributionPercentage = 0; // or another appropriate value or action
        }

        $projectTotalContribution[$projectName] = [
            'TotalContribution' => $totalContribution,
            'ContributionPercentage' => $contributionPercentage,
        ];
    } else {
        $projectTotalContribution[$projectName] = null;
    }
}

// Sort the projects by Total Contribution in descending order
arsort($projectTotalContribution);

// Output the Combined Table
echo "<!DOCTYPE html>";
echo "<html lang='en'>";
echo "<head>";
echo "<meta charset='UTF-8'>";
echo "<meta name='viewport' content='width=device-width, initial-scale=1.0'>";
echo "<title>Total Project Contribution</title>";
echo "<script type='text/javascript' src='https://www.gstatic.com/charts/loader.js'></script>";
echo "</head>";
echo "<body>";
echo "<h1>Total Project Contribution</h1>";
echo "<button id='download-csv' class='btn btn-primary float-end' style='margin-bottom: 10px;'>Download CSV</button>";
echo "<table class='table table-bordered table-striped'>";
echo "<thead>";
echo "<tr>";
echo "<th>S.No.</th>"; // Add S.No. column header
echo "<th>Client Name</th>";
echo "<th>Project Name</th>";
echo "<th>Contract Value</th>"; // Add Contract Value column header
echo "<th>Project Total Income</th>";
echo "<th>Cumulative Direct Labour</th>";
echo "<th>Cumulative Direct Material Cost</th>";
echo "<th>Total Contribution</th>"; // Add Total Contribution column header
echo "<th>Project Contribution Percentage</th>"; // Add Contribution Percentage column header
echo "</tr>";
echo "</thead>";
echo "<tbody>";

// Initialize a counter for S.No.
$serialNumber = 1;

foreach ($projectTotalContribution as $projectName => $contributionData) {
    echo "<tr>";
    echo "<td>$serialNumber</td>"; // Output the S.No.
    echo "<td>{$projectClientNames[$projectName]}</td>";
    echo "<td>$projectName</td>";

    // Check if Contract Value exists for the project
    if (isset($projectCumulative[$projectName]['ContractValue'])) {
        echo "<td>" . number_format($projectCumulative[$projectName]['ContractValue'], 2) . "</td>";
    } else {
        echo "<td>N/A</td>"; // Output N/A if Contract Value is not available
    }

    echo "<td>" . number_format($projectTotalIncome[$projectName], 2) . "</td>";

    if (isset($projectCumulative[$projectName])) {
        echo "<td>" . number_format($projectCumulative[$projectName]['CumulativeDL'], 2) . "</td>";
        echo "<td>" . number_format($projectCumulative[$projectName]['CumulativeDM'], 2) . "</td>";

        if ($contributionData !== null) {
            echo "<td>" . number_format($contributionData['TotalContribution'], 2) . "</td>";
            echo "<td>" . number_format($contributionData['ContributionPercentage'], 2) . "%</td>";
        } else {
            echo "<td>N/A</td>"; // Output N/A if Contribution Data is not available
            echo "<td>N/A</td>"; // Output N/A if Contribution Data is not available
        }
    } else {
        echo "<td>N/A</td>"; // Output N/A if Cumulative Data is not available
        echo "<td>N/A</td>"; // Output N/A if Cumulative Data is not available
        echo "<td>N/A</td>"; // Output N/A if Contribution Data is not available
        echo "<td>N/A</td>"; // Output N/A if Contribution Data is not available
    }

    echo "</tr>";
    $serialNumber++; // Increment the S.No.
}

echo "</tbody>";
echo "</table>";

// JavaScript function to trigger CSV download
echo "<script>";
echo "function downloadCSV() {";
echo "const table = document.querySelector('.table');";
echo "const rows = table.querySelectorAll('tr');";
echo "const csv = [];";

echo "rows.forEach((row) => {";
echo "const rowData = [];";
echo "row.querySelectorAll('td, th').forEach((cell) => {";
echo "rowData.push(cell.textContent);";
echo "});";
echo "csv.push(rowData.join(','));";
echo "});";

echo "const blob = new Blob([csv.join('\\n')], { type: 'text/csv' });";
echo "const link = document.createElement('a');";
echo "link.href = URL.createObjectURL(blob);";
echo "link.download = 'total_project_contribution.csv';";
echo "link.style.display = 'none';";
echo "document.body.appendChild(link);";
echo "link.click();";
echo "document.body.removeChild(link);";
echo "}";
echo "</script>";

// Add click event listener to the download button
echo "<script>";
echo "document.getElementById('download-csv').addEventListener('click', downloadCSV);";
echo "</script>";

// Close the HTML body and document
echo "</body>";
echo "</html>";

// Close the database connection
mysqli_close($conn);
?>